@@ -35,6 +35,14 @@ bool SignalIndicator::simLocked() const
     return m_modem->unlockRequired() == MM_MODEM_LOCK_SIM_PIN;
 }
 
+bool SignalIndicator::simEmpty() const
+{
+    if (!m_modem) {
+        return false;
+    }
+    return m_modemDevice && m_modemDevice->sim() && m_modemDevice->sim()->uni() == QStringLiteral("/");
+}
+
 bool SignalIndicator::available() const
 {
     return !ModemManager::modemDevices().isEmpty();
@@ -42,7 +50,7 @@ bool SignalIndicator::available() const
 
 bool SignalIndicator::mobileDataSupported() const
 {
-    return m_nmModem && m_modemDevice->sim();
+    return m_nmModem && m_modemDevice->sim() && !simEmpty();
 }
 
 bool SignalIndicator::mobileDataEnabled() const
@@ -73,6 +81,11 @@ bool SignalIndicator::mobileDataEnabled() const
     return false;
 }
 
+bool SignalIndicator::needsAPNAdded() const
+{
+    return m_nmModem && mobileDataSupported() && m_nmModem->availableConnections().count() == 0;
+}
+
 void SignalIndicator::setMobileDataEnabled(bool enabled)
 {
     if (!m_nmModem) {
@@ -137,10 +150,16 @@ void SignalIndicator::updateModem()
             });
         }
     }
+    
+    connect(m_modemDevice->sim().get(), &ModemManager::Sim::simIdentifierChanged, this, &SignalIndicator::simEmptyChanged);
 
-    connect(m_modem.get(), &ModemManager::Modem::signalQualityChanged, this, &SignalIndicator::strengthChanged);
-    connect(m_3gppModem.get(), &ModemManager::Modem3gpp::operatorNameChanged, this, &SignalIndicator::nameChanged);
-    connect(m_modem.get(), &ModemManager::Modem::unlockRequiredChanged, this, &SignalIndicator::simLockedChanged);
+    if (m_modem) {
+        connect(m_modem.get(), &ModemManager::Modem::signalQualityChanged, this, &SignalIndicator::strengthChanged);
+        connect(m_modem.get(), &ModemManager::Modem::unlockRequiredChanged, this, &SignalIndicator::simLockedChanged);
+    }
+    if (m_3gppModem) {
+        connect(m_3gppModem.get(), &ModemManager::Modem3gpp::operatorNameChanged, this, &SignalIndicator::nameChanged);
+    }
 
     Q_EMIT mobileDataSupportedChanged();
     Q_EMIT nameChanged();
