@@ -20,9 +20,11 @@ class SignalIndicator : public QObject
     Q_PROPERTY(int strength READ strength NOTIFY strengthChanged)
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
     Q_PROPERTY(bool simLocked READ simLocked NOTIFY simLockedChanged)
+    Q_PROPERTY(bool simEmpty READ simEmpty NOTIFY simEmptyChanged)
     Q_PROPERTY(bool available READ available NOTIFY availableChanged)
     Q_PROPERTY(bool mobileDataSupported READ mobileDataSupported NOTIFY mobileDataSupportedChanged)
     Q_PROPERTY(bool mobileDataEnabled READ mobileDataEnabled WRITE setMobileDataEnabled NOTIFY mobileDataEnabledChanged)
+    Q_PROPERTY(bool needsAPNAdded READ needsAPNAdded NOTIFY mobileDataEnabledChanged)
 
 public:
     SignalIndicator();
@@ -30,9 +32,11 @@ public:
     int strength() const;
     QString name() const;
     bool simLocked() const;
+    bool simEmpty() const;
     bool available() const;
     bool mobileDataSupported() const;
     bool mobileDataEnabled() const;
+    bool needsAPNAdded() const;
 
     void setMobileDataEnabled(bool enabled);
 
@@ -40,6 +44,7 @@ Q_SIGNALS:
     void strengthChanged();
     void nameChanged();
     void simLockedChanged();
+    void simEmptyChanged();
     void availableChanged();
     void mobileDataSupportedChanged();
     void mobileDataEnabledChanged();
